#!/usr/bin/env python
"""
Command line utility to add AGFM data files into an SQLite database file.

AGFM == hysteresis

     Copyright (C) 2005  Kurt Schwehr

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

$Id: agfmsql.py,v 1.4 2005/10/29 15:31:06 schwehr Exp $
"""

# These values end up in the pydoc web page
__version__ = '$Revision: 1.4 $'.split()[1] # See man ident
__date__ = '$Date: 2005/10/29 15:31:06 $' # FIX: pull out just the date
__author__ = 'Kurt Schwehr'

import sqlite
import agfm
import os
import sys

from pmag_verbosity import BOMBASTIC,VERBOSE,TRACE,TERSE,ALWAYS
import pmag_verbosity

if __name__ == "__main__":
    from optparse import OptionParser

    myparser = OptionParser(usage="%prog [options] hyst1.raw hyst2.raw hyst3.raw ...",
                            version="%prog-"+__version__)

    myparser.add_option('-d','--database',dest='dbName',default='pmag.db',type='string',
                        help='Database filename [default: %default]')
    myparser.add_option('-D','--delete',dest='delete',default=False,action='store_true',
                        help='delete previous db if it exists  [default: %default]')

    myparser.add_option('-t','--sql-table',dest='table',default='hyst',type='string',
                        help='Name of the database table. [default: %default]')

    myparser.add_option('-c','--no-hyst-crunch',dest='hystCrunch',default=True,action='store_false',
                        help='Do not run hystcrunch to process')

    myparser.add_option('--no-sql-create',dest='sqlCreate',default=True, action='store_false',
                        help='Generate a SQL CREATE statement that can be used to make a new table')

    myparser.add_option('-b','--bpsio-style-name',dest='bpsioName',default=False, action='store_true',
                        help='use first 15 characters of the comment as the sample name')

    myparser.add_option('-s','--skip-std','--skip-standard',dest='skipStds',default=False, action='store_true',
                        help='skip the measurements of the standard')

    pmag_verbosity.addVerbosityOptions(myparser)


    # FIX: add flags for the type of hystcrunch

    (options,args) = myparser.parse_args()

    
    if options.delete and os.access(options.dbName,os.W_OK):
        os.remove(options.dbName)
    cx = sqlite.connect(options.dbName)
    cu = cx.cursor()

    if options.sqlCreate:
        if options.verbosity >= TRACE: print 'creating db table',options.table
        s = agfm.sqlCreate(options.table)
        if options.verbosity >= BOMBASTIC: print '  ',s
        cu.execute(s)

    for file in args:
        if options.verbosity>=TERSE: print file
        sample = agfm.agfm(file,options.hystCrunch,options.verbosity)

        if sample.header['comment'][0:2] == 'ni':
            if options.verbosity >= TRACE: print 'skipping standard file',file
            continue

        if options.bpsioName:
            comment = sample.header['comment']
            if 'ni'==comment[0:2]:
                # standard
                name = comment[0:3]
            else:
                name = comment[0:15]
            sample.header['samplename'] = name
        ins = sample.getSqlInsertStr(options.table)
        if options.verbosity >= BOMBASTIC:
            print ' inserting file :',file,'\n',ins
        cu.execute(ins)

    if options.verbosity>=TRACE: print 'committing database...'
    cx.commit()

    if options.verbosity>=TRACE: print 'have a magnetic day'
    
